pub async fn count_by_module(
conn: &mut PgConnection,
) -> ModelResult<Vec<ModuleRegistrationTotals>>Expand description
failed_count is failed_permanent and misregistered only, so the columns do not add up to
the total by design.
pub async fn count_by_module(
conn: &mut PgConnection,
) -> ModelResult<Vec<ModuleRegistrationTotals>>failed_count is failed_permanent and misregistered only, so the columns do not add up to
the total by design.