mark_partially_registered

Function mark_partially_registered 

pub async fn mark_partially_registered(
    conn: &mut PgConnection,
    id: Uuid,
) -> ModelResult<DateTime<Utc>>
Notes that verify saw only the assessment item attainment, keeping the first sighting, and returns when that was.