recovery_request_item_id

Function recovery_request_item_id 

pub fn recovery_request_item_id(
    registration_id: Uuid,
    verify_attempt_count: i32,
) -> String
The item id Suotar sees for one look through a student’s attainments for a submission we lost track of.