pub async fn schedule_next_attempts(
conn: &mut PgConnection,
scheduled: &[(Uuid, DateTime<Utc>)],
) -> ModelResult<()>Expand description
schedule_next_attempt for a whole batch, each row with its own time.
pub async fn schedule_next_attempts(
conn: &mut PgConnection,
scheduled: &[(Uuid, DateTime<Utc>)],
) -> ModelResult<()>schedule_next_attempt for a whole batch, each row with its own time.