pub struct AttentionRegistration {Show 23 fields
pub id: Uuid,
pub user_id: Uuid,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub email: Option<String>,
pub course_id: Uuid,
pub course_name: String,
pub course_module_id: Uuid,
pub course_module_name: Option<String>,
pub state: CreditRegistrationState,
pub state_entered_at: DateTime<Utc>,
pub error_code: Option<CreditRegistrationErrorCode>,
pub attempt_count: i32,
pub needs_admin_attention: bool,
pub next_attempt_at: DateTime<Utc>,
pub student_number: Option<String>,
pub stuck_in_state: bool,
pub permanent_error: bool,
pub retry_window_expired: bool,
pub misregistered: bool,
pub too_many_attempts: bool,
pub outcome_uncertain: bool,
pub flagged_by_pipeline: bool,
}Expand description
One row the Errors tab wants a human to look at, with the detectors that picked it.
Fields
id: Uuiduser_id: Uuidfirst_name: Option<String>last_name: Option<String>email: Option<String>course_id: Uuidcourse_name: Stringcourse_module_id: Uuidcourse_module_name: Option<String>state: CreditRegistrationStatestate_entered_at: DateTime<Utc>error_code: Option<CreditRegistrationErrorCode>attempt_count: i32needs_admin_attention: boolnext_attempt_at: DateTime<Utc>student_number: Option<String>stuck_in_state: boolpermanent_error: boolretry_window_expired: boolmisregistered: booltoo_many_attempts: booloutcome_uncertain: boolflagged_by_pipeline: boolTrait Implementations
Sourceimpl Clone for AttentionRegistration
impl Clone for AttentionRegistration
Sourcefn clone(&self) -> AttentionRegistration
fn clone(&self) -> AttentionRegistration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttentionRegistration
impl Debug for AttentionRegistration
Sourceimpl PartialEq for AttentionRegistration
impl PartialEq for AttentionRegistration
impl StructuralPartialEq for AttentionRegistration