pub struct CreditRegistrationErrorCodeCount {
pub error_code: CreditRegistrationErrorCode,
pub in_flight_count: i64,
pub terminal_failure_count: i64,
}Expand description
Live rows carrying an error code, split by whether the pipeline is still working on them.
Fields
error_code: CreditRegistrationErrorCodein_flight_count: i64terminal_failure_count: i64Trait Implementations
Sourceimpl Clone for CreditRegistrationErrorCodeCount
impl Clone for CreditRegistrationErrorCodeCount
Sourcefn clone(&self) -> CreditRegistrationErrorCodeCount
fn clone(&self) -> CreditRegistrationErrorCodeCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreditRegistrationErrorCodeCount
impl PartialEq for CreditRegistrationErrorCodeCount
Sourcefn eq(&self, other: &CreditRegistrationErrorCodeCount) -> bool
fn eq(&self, other: &CreditRegistrationErrorCodeCount) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreditRegistrationErrorCodeCount