pub struct CreditRegistrationThroughputDay {
pub day: DateTime<Utc>,
pub registered_count: i64,
pub other_success_count: i64,
pub failed_count: i64,
}Expand description
One day of terminal outcomes, for the throughput series.
Fields
day: DateTime<Utc>registered_count: i64other_success_count: i64failed_count: i64Trait Implementations
Sourceimpl Clone for CreditRegistrationThroughputDay
impl Clone for CreditRegistrationThroughputDay
Sourcefn clone(&self) -> CreditRegistrationThroughputDay
fn clone(&self) -> CreditRegistrationThroughputDay
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreditRegistrationThroughputDay
impl PartialEq for CreditRegistrationThroughputDay
Sourcefn eq(&self, other: &CreditRegistrationThroughputDay) -> bool
fn eq(&self, other: &CreditRegistrationThroughputDay) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreditRegistrationThroughputDay