pub struct OldestNonTerminalRegistration {
pub id: Uuid,
pub state: CreditRegistrationState,
pub state_entered_at: DateTime<Utc>,
}Expand description
The row that has been waiting longest for the pipeline to do something with it.
Fields
id: Uuidstate: CreditRegistrationStatestate_entered_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for OldestNonTerminalRegistration
impl Clone for OldestNonTerminalRegistration
Sourcefn clone(&self) -> OldestNonTerminalRegistration
fn clone(&self) -> OldestNonTerminalRegistration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for OldestNonTerminalRegistration
impl PartialEq for OldestNonTerminalRegistration
Sourcefn eq(&self, other: &OldestNonTerminalRegistration) -> bool
fn eq(&self, other: &OldestNonTerminalRegistration) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OldestNonTerminalRegistration