pub struct PayloadSnapshot {
pub student_number: String,
pub sisu_person_id: String,
pub uh_course_code: String,
pub selected_enrolment_id: Option<String>,
pub selected_enrolment_kind: Option<String>,
pub selected_enrolment_realisation_id: Option<String>,
pub attainment_date: NaiveDate,
pub attainment_language: String,
pub grade_scale_id: String,
pub grade_id: String,
pub credits: f32,
}Expand description
Frozen copy of what we are about to submit. Written once, before the row leaves
checking_enrolment: a later regrade must not alter a submitted row.
Fields
student_number: Stringsisu_person_id: Stringuh_course_code: Stringselected_enrolment_id: Option<String>selected_enrolment_kind: Option<String>selected_enrolment_realisation_id: Option<String>attainment_date: NaiveDateattainment_language: Stringgrade_scale_id: Stringgrade_id: Stringcredits: f32Trait Implementations
Sourceimpl Clone for PayloadSnapshot
impl Clone for PayloadSnapshot
Sourcefn clone(&self) -> PayloadSnapshot
fn clone(&self) -> PayloadSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PayloadSnapshot
impl Debug for PayloadSnapshot
Sourceimpl PartialEq for PayloadSnapshot
impl PartialEq for PayloadSnapshot
impl StructuralPartialEq for PayloadSnapshot