pub async fn mark_partially_registered(
conn: &mut PgConnection,
id: Uuid,
) -> ModelResult<DateTime<Utc>>Expand description
Notes that verify saw only the assessment item attainment, keeping the first sighting, and returns when that was.
pub async fn mark_partially_registered(
conn: &mut PgConnection,
id: Uuid,
) -> ModelResult<DateTime<Utc>>Notes that verify saw only the assessment item attainment, keeping the first sighting, and returns when that was.